package com.xkrs.dao;

import com.xkrs.model.entity.Fire;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @Author: XinYi Song
 * @Date: 2022/2/8 17:12
 */
@Component
public interface FireDao extends JpaRepository<Fire,Long>, JpaSpecificationExecutor<Fire> {

    /**
     * 根据报警编码查询火情信息
     * @param code
     * @return
     */
    Fire findByAlarmCode(String code);

    /**
     * 根据报警编码修改图片信息
     * @param code
     * @param picturePath
     */
    @Modifying(clearAutomatically=true)
    @Query(value = "update fire set picture_path = ?2 where alarm_code = ?1",nativeQuery = true)
    void updatePicturePath(String code, String picturePath);

    /**
     * 根据设备编码获取火情的信息
     * @param code
     * @return
     */
    List<Fire> findByDeviceCode(String code);

    /**
     * 查询最新的300条火情信息
     * @return
     */
    @Query(value = "select * from fire order by alarm_date desc limit 300",nativeQuery = true)
    List<Fire> findThreeHundredData();
}
